
#Region " Module Details "

'Author         :   Common Class
'Description    :   Common Data level Functions.

#End Region

#Region " Imports "

Imports System.Data
Imports System.Data.OleDb
Imports System.Data.Odbc
Imports System.Configuration

#End Region

Public Class dCommon

#Region " Declaration "

    Private Conn As OleDbConnection
    Private ConnectStr = "Provider=SQLOLEDB.1;Persist Security Info=False;User ID=" & _
            Configuration.ConfigurationSettings.AppSettings("USERID") & _
            ";Password=" & Configuration.ConfigurationSettings.AppSettings("PASSWORD") & _
            ";Initial Catalog=" & Configuration.ConfigurationSettings.AppSettings("DATABASE") & _
            ";Data Source=" & Configuration.ConfigurationSettings.AppSettings("DATABASESERVER")

#End Region

#Region " Connection "

    Private Sub ConnOpen()
        Try
            If Conn Is Nothing Then
                Conn = New System.Data.OleDb.OleDbConnection
            End If
            If Conn.State = ConnectionState.Open Then
                Conn.Close()
            End If
            Conn.ConnectionString = ConnectStr
            Conn.Open()
        Catch ex As Exception
            Throw ex
        End Try
    End Sub

    Private Sub ConnClose()
        Try
            If Not Conn Is Nothing Then
                If Conn.State = ConnectionState.Open Then
                    Conn.Close()
                End If
            End If
        Catch ex As Exception
            Throw ex
        End Try
    End Sub

#End Region

#Region " Open DataSet "

    Public Overloads Function OpenDataSet(ByVal TableName As String, ByVal strQuery As String, Optional ByVal dSet As DataSet = Nothing, Optional ByVal ConnType As String = "Oracle") As DataSet
        Dim dAdapter As OleDbDataAdapter
        Dim dTable As DataTable
        Try
            If dSet Is Nothing Then
                dSet = New System.Data.DataSet
            End If

            'Check Whether the table with same name exists otherwise it will remove.
            If TableName.Trim <> "" Then
                If dSet.Tables.Count > 0 Then
                    For Each dTable In dSet.Tables
                        If dTable.TableName = TableName Then
                            dSet.Tables.Remove(dTable.TableName)
                            Exit For
                        End If
                    Next
                End If
            End If
            ConnOpen()

            dAdapter = New OleDbDataAdapter(strQuery, Conn)
            If TableName.Trim <> "" Then
                dAdapter.Fill(dSet, TableName)
            Else
                dAdapter.Fill(dSet)
            End If

            Return dSet
        Catch ex As Exception
            Throw ex
        Finally
            dTable = Nothing
            dAdapter = Nothing
            ConnClose()
        End Try
    End Function

    Public Overloads Function OpenDataSet(ByVal strQuery As String, Optional ByVal dSet As DataSet = Nothing) As DataSet
        Dim dAdapter As OleDbDataAdapter
        Try
            If dSet Is Nothing Then
                dSet = New System.Data.DataSet
            End If

            ConnOpen()
            dAdapter = New OleDbDataAdapter(strQuery, Conn)
            dAdapter.Fill(dSet)

            Return dSet
        Catch ex As Exception
            Throw ex
        Finally
            dAdapter = Nothing
            ConnClose()
        End Try
    End Function

#End Region

#Region " Update DataSet "

    Public Function UpdateDataSet(ByVal dSet As DataSet, Optional ByVal strQuery As String = "") As DataSet
        Dim dAdapter As OleDbDataAdapter
        Dim cBuilder As OleDbCommandBuilder
        Dim dTable As DataTable
        Dim strSQL As String, TableName As String

        Try
            ConnOpen()
            If strQuery.Trim <> String.Empty Then
                strSQL = strQuery
                dAdapter = New OleDbDataAdapter(strSQL, Conn)
                cBuilder = New OleDbCommandBuilder(dAdapter)
                dAdapter.Update(dSet.Tables(0))
            Else
                For Each dTable In dSet.Tables
                    TableName = dTable.TableName
                    strSQL = "Select * From " & TableName
                    dAdapter = New OleDbDataAdapter(strSQL, Conn)
                    cBuilder = New OleDbCommandBuilder(dAdapter)
                    dAdapter.Update(dSet, TableName)
                Next
            End If

            Return dSet
        Catch ex As Exception
            Throw ex
        Finally
            dTable = Nothing
            cBuilder = Nothing
            dAdapter = Nothing
            ConnClose()
        End Try
    End Function

    Public Function UpdateDataTable(ByVal dTbl As DataTable, Optional ByVal strQuery As String = "") As DataTable
        Dim dAdapter As OleDbDataAdapter
        Dim cBuilder As OleDbCommandBuilder
        Dim strSQL As String, TableName As String

        Try
            ConnOpen()
            If strQuery.Trim <> String.Empty Then
                strSQL = strQuery
                dAdapter = New OleDbDataAdapter(strSQL, Conn)
                cBuilder = New OleDbCommandBuilder(dAdapter)
                dAdapter.Update(dTbl)
            Else
                TableName = dTbl.TableName
                strSQL = "Select * From " & TableName
                dAdapter = New OleDbDataAdapter(strSQL, Conn)
                cBuilder = New OleDbCommandBuilder(dAdapter)
                dAdapter.Update(dTbl)
            End If

            Return dTbl
        Catch ex As Exception
            Throw ex
        Finally
            cBuilder = Nothing
            dAdapter = Nothing
            ConnClose()
        End Try
    End Function

#End Region

#Region " Execute Scalar / Query "

    Public Function ExecuteScalar(ByVal SqlStr As String) As String
        Dim Cmd As OleDbCommand
        Dim Str As String
        Try
            ConnOpen()
            Cmd = New OleDbCommand(SqlStr, Conn)
            Str = Cmd.ExecuteScalar()
            Return Str
        Catch ex As Exception
            Throw ex
        Finally
            Cmd = Nothing
            ConnClose()
        End Try
    End Function

    Public Function ExecuteQuery(ByVal strQuery As String) As Integer
        Dim RecordsAffected As Integer
        Dim Cmd As OleDbCommand
        Try
            ConnOpen()
            Cmd = New OleDbCommand(strQuery, Conn)
            RecordsAffected = Cmd.ExecuteNonQuery

            Return RecordsAffected
        Catch ex As Exception
            Throw ex
        Finally
            Cmd = Nothing
            ConnClose()
        End Try
    End Function

#End Region

#Region " Delete Records "

    Public Function DeleteRecord(ByVal SqlStr As String) As Boolean
        Dim dset As New DataSet
        Dim dRow As DataRow
        Try
            dset = OpenDataSet(SqlStr)

            If dset.Tables(0).Rows.Count <> 0 Then
                For Each dRow In dset.Tables(0).Rows
                    dRow.Delete()
                Next
                UpdateDataSet(dset, SqlStr)
            End If
        Catch ex As Exception
            Throw ex
        Finally
            dset = Nothing
            ConnClose()
        End Try
    End Function

    Public Function DeleteRecords(ByVal SqlStr As String) As Boolean
        Dim Cmd As New OleDbCommand
        Dim intAffected As Int32
        Try
            ConnOpen()
            Cmd.CommandText = SqlStr
            Cmd.Connection = Conn
            Cmd.CommandType = CommandType.Text
            intAffected = Cmd.ExecuteNonQuery
        Catch ex As Exception
            Throw ex
        Finally
            Cmd = Nothing
            ConnClose()
        End Try
    End Function

#End Region

#Region " Other Functions "

    Public Function GetNextAutoNo(ByVal TableName As String, ByVal FieldName As String) As Int32
        Dim strQuery As String
        Dim dSet As New DataSet
        Try
            strQuery = "Select Max(" & FieldName & ") As AutoNo From " & TableName
            dSet = OpenDataSet(TableName, strQuery)

            If dSet.Tables(0).Rows(0).IsNull(0) Then
                Return 1
            Else
                Return dSet.Tables(0).Rows(0)("AutoNo") + 1
            End If
        Catch ex As Exception
            Throw ex
        Finally
            dSet = Nothing
        End Try
    End Function

    Public Function GetRecordCount(ByVal TableName As String, ByVal FieldName As String, Optional ByVal WhereCondition As String = "") As Integer
        Dim dTable As DataTable
        Dim SqlStr As String
        If WhereCondition.Trim = String.Empty Then
            SqlStr = "Select Count(" & FieldName & ") from " & TableName
        Else
            SqlStr = "Select Count(" & FieldName & ") from " & TableName & " Where " & WhereCondition
        End If

        dTable = OpenDataSet("", SqlStr).Tables(0)
        Return dTable.Rows.Count
    End Function

    Public Function GetEmptyTable(ByVal mTableName As String) As DataTable
        Dim dAdapter As OleDbDataAdapter
        Dim mStrQuery As String
        Dim dTable As DataTable
        Try

            mStrQuery = " select * from " & mTableName & " where 1=2"
            ConnOpen()
            dTable = OpenDataSet(mTableName, mStrQuery).Tables(mTableName)

            Return dTable
        Catch ex As Exception
            Throw ex
        Finally
            dAdapter = Nothing
            ConnClose()
        End Try
    End Function

#End Region

End Class
